This is a test of HTML templates

#### Date: Mar 1, 2021

## This is a test of HTML templates

Note: When using HTML templates, the DocOnce file cannot have a title (to avoid generating a header). It should neither have an author.

# This is a 7 heading

Here is some code:

    class Diff:
        def __init__(self, f, h=1E-5):
            self.f = f
            self.h = float(h)

    class Forward1(Diff):
        def __call__(self, x):
            f, h = self.f, self.h
            return (f(x+h) - f(x))/h

## This is a 5 heading

The template can be any HTML file with header and footer and three possible slots: title, date and main, where main will become the DocOnce file (the main body of text), title is the first heading in the DocOnce file, and date is extracted from the DocOnce file (if present).